@@ -1,4 +1,4 @@
-/* Copyright (c) 2004, Colin O'Flynn <coflynn@newae.com>
+/* Copyright (c) 2004,2005, Colin O'Flynn <coflynn@newae.com>
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iocan128.h,v 1.9.2.3 2005/07/19 15:02:13 aesok Exp $ */
+/* $Id: iocan128.h,v 1.9.2.5 2005/07/31 21:02:49 joerg_wunsch Exp $ */
 
 /* This file is based largely on:
    - iom128.h by Peter Jansen (bit defines)
@@ -124,6 +124,14 @@
 #define EEARL  _SFR_IO8(0x21)
 #define EEARH  _SFR_IO8(0x22)
 
+/* 6-char sequence denoting where to find the EEPROM registers in memory space.
+   Adresses denoted in hex syntax with uppercase letters. Used by the EEPROM
+   subroutines.
+   First two letters:  EECR address.
+   Second two letters: EEDR address.
+   Last two letters:   EEAR address.  */
+#define __EEPROM_REG_LOCATIONS__ 1F2021
+
 /* RegDef:  General Timer/Counter Control Register */
 #define GTCCR  _SFR_IO8(0x23)
 
@@ -824,9 +832,14 @@
 #define    ADPS0        0
 /* End Register Bits */
 
+/* 
+   The ADHSM bit has been removed from all documentation, 
+   as being not needed at all since the comparator has proven 
+   to be fast enough even without feeding it more power.
+*/
+
 /* Register Bits [ADCSRB]  */
 /* ADC Control and status register - ADCSRB */
-#define    ADHSM        7
 #define    ACME         6
 #define    ADTS2        2
 #define    ADTS1        1
