@@ -1,4 +1,4 @@
-/* Copyright (c) 2004 Eric B. Weddington
+/* Copyright (c) 2004,2005, Eric B. Weddington
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom165.h,v 1.2.2.2 2005/07/19 15:02:13 aesok Exp $ */
+/* $Id: iom165.h,v 1.2.2.3 2005/07/31 21:02:49 joerg_wunsch Exp $ */
 
 /* avr/iom165.h - definitions for ATmega165 */
 
@@ -120,6 +120,14 @@
 #define EEARL   _SFR_IO8(0x21)
 #define EEARH   _SFR_IO8(0X22)
 
+/* 6-char sequence denoting where to find the EEPROM registers in memory space.
+   Adresses denoted in hex syntax with uppercase letters. Used by the EEPROM
+   subroutines.
+   First two letters:  EECR address.
+   Second two letters: EEDR address.
+   Last two letters:   EEAR address.  */
+#define __EEPROM_REG_LOCATIONS__ 1F2021
+
 #define GTCCR   _SFR_IO8(0x23)
 #define PSR10   0
 #define PSR2    1
