@@ -30,7 +30,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom169.h,v 1.17.2.4 2005/07/19 15:02:13 aesok Exp $ */
+/* $Id: iom169.h,v 1.17.2.5 2005/07/31 21:02:49 joerg_wunsch Exp $ */
 
 /* iom169.h - definitions for ATmega169 */
 
@@ -115,6 +115,14 @@
 #define EEARL  _SFR_IO8(0x21)
 #define EEARH  _SFR_IO8(0X22)
 
+/* 6-char sequence denoting where to find the EEPROM registers in memory space.
+   Adresses denoted in hex syntax with uppercase letters. Used by the EEPROM
+   subroutines.
+   First two letters:  EECR address.
+   Second two letters: EEDR address.
+   Last two letters:   EEAR address.  */
+#define __EEPROM_REG_LOCATIONS__ 1F2021
+
 /* General Timer/Counter Control Register */
 #define GTCCR  _SFR_IO8(0x23)
 
