@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom64.h,v 1.9.2.1 2005/07/19 15:02:13 aesok Exp $ */
+/* $Id: iom64.h,v 1.9.2.2 2005/07/28 17:47:57 aesok Exp $ */
 
 /* avr/iom64.h - defines for ATmega64 
 
@@ -682,9 +682,14 @@
 #define    WDP1         1
 #define    WDP0         0
 
+/* 
+   The ADHSM bit has been removed from all documentation, 
+   as being not needed at all since the comparator has proven 
+   to be fast enough even without feeding it more power.
+*/
+
 /* Special Function I/O Register - SFIOR */
 #define    TSM          7
-#define    ADHSM        4
 #define    ACME         3
 #define    PUD          2
 #define    PSR0         1
