@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iotn28.h,v 1.5 2004/11/01 22:23:56 arcanum Exp $ */
+/* $Id: iotn28.h,v 1.5.2.1 2005/07/19 15:02:13 aesok Exp $ */
 
 /* avr/iotn28.h - definitions for ATtiny28 */
 
@@ -150,12 +150,6 @@
 #define WDP1	1
 #define WDP0	0
 
-/* EECR */
-#define EERIE	3
-#define EEMWE	2
-#define EEWE	1
-#define EERE	0
-
 /*
    PA2 = IR
  */
