@@ -1,4 +1,5 @@
 /* Copyright (c) 2002, Marek Michalkiewicz
+   Copyright (c) 2004, Joerg Wunsch
 
    Portions of documentation Copyright (c) 1990, 1991, 1993, 1994
    The Regents of the University of California.
@@ -10,11 +11,16 @@
 
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
+
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in
      the documentation and/or other materials provided with the
      distribution.
 
+   * Neither the name of the copyright holders nor the names of
+     contributors may be used to endorse or promote products derived
+     from this software without specific prior written permission.
+
   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -27,7 +33,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
 
-  $Id: stdlib.h,v 1.14.2.5 2004/12/14 23:23:59 joerg_wunsch Exp $
+  $Id: stdlib.h,v 1.22 2004/12/14 22:56:51 joerg_wunsch Exp $
 */
 
 #ifndef _STDLIB_H_
@@ -58,14 +64,14 @@ extern "C" {
 /*@{*/
 /** Result type for function div(). */
 typedef struct {
-	int quot;
-	int rem;
+	int quot;                   /**< The Quotient. */
+	int rem;                    /**< The Remainder. */
 } div_t;
 
 /** Result type for function ldiv(). */
 typedef struct {
-	long quot;
-	long rem;
+	long quot;                  /**< The Quotient. */
+	long rem;                   /**< The Remainder. */
 } ldiv_t;
 
 /** Comparision function type for qsort(), just for convenience. */
@@ -325,6 +331,25 @@ extern char *__malloc_heap_end;
 */
 extern void *calloc(size_t __nele, size_t __size) __ATTR_MALLOC__;
 
+/**
+   The realloc() function tries to change the size of the region
+   allocated at \c ptr to the new \c size value.  It returns a
+   pointer to the new region.  The returned pointer might be the
+   same as the old pointer, or a pointer to a completely different
+   region.
+
+   The contents of the returned region up to either the old or the new
+   size value (whatever is less) will be identical to the contents of
+   the old region, even in case a new region had to be allocated.
+
+   It is acceptable to pass \c ptr as NULL, in which case realloc()
+   will behave identical to malloc().
+
+   If the new memory cannot be allocated, realloc() returns NULL, and
+   the region at \c ptr will not be changed.
+*/
+extern void *realloc(void *__ptr, size_t __size) __ATTR_MALLOC__;
+
 /**
      The strtod() function converts the initial portion of the string pointed
      to by \c nptr to double representation.
@@ -604,7 +629,6 @@ extern char *dtostrf(double __val, char __width, char __prec, char *__s);
 
 #if 0  /* not yet implemented */
 extern int atexit(void (*)(void));
-extern void *realloc(void *, size_t);
 #endif
 
 #ifdef __cplusplus
